=======
History
=======

0.6.0 (2020-04-05)
------------------

* Update get devices method
* Update requirements
* Make SSL verification default

0.5.0 (2016-07-12)
------------------

* Add filtering options for the `get_data` method

0.1.0 (2016-04-04)
------------------

* First release on PyPI.
